@@ -44,7 +44,7 @@ static USER_OBJECT_ makeSchemaReference(xmlSchemaPtr ref);
 
 
 USER_OBJECT_
-RS_XML(libxmlVersionRuntime)()
+RS_XML(libxmlVersionRuntime)(void)
 {
     return(mkString(*__xmlParserVersion()));
 }
@@ -55,7 +55,7 @@ RS_XML(getDefaultValiditySetting)(USER_OBJECT_ val)
 {
 #ifdef HAVE_VALIDITY
 
- extern int xmlDoValidityCheckingDefaultValue;
+// extern int xmlDoValidityCheckingDefaultValue;
  USER_OBJECT_ ans;
  ans = NEW_INTEGER(1);
  INTEGER_DATA(ans)[0] = xmlDoValidityCheckingDefaultValue;
@@ -1023,7 +1023,7 @@ RS_XML(notifyNamespaceDefinition)(USER_OBJECT_ arg, R_XMLSettings *parserSetting
 #endif
 
 USER_OBJECT_
-RS_XML(libxmlVersion)()
+RS_XML(libxmlVersion)(void)
 {
  USER_OBJECT_ ans;
  unsigned int val;
@@ -1447,7 +1447,7 @@ RS_XML(AttributeList)(xmlNodePtr node, R_XMLSettings *parserSettings)
          if(atts->name) {
            if(addNSPrefix && atts->ns && atts->ns->prefix) {
              char buf[400];
-             sprintf(buf, "%s:%s", atts->ns->prefix, atts->name);
+             snprintf(buf, 400, "%s:%s", atts->ns->prefix, atts->name);
              SET_STRING_ELT(ans_names, i, ENC_COPY_TO_USER_STRING(buf));
 	   } else
              SET_STRING_ELT(ans_names, i, ENC_COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(atts->name)));
