@@ -107,8 +107,7 @@ RS_XML(getDTD)(USER_OBJECT_ dtdFileName, USER_OBJECT_ externalId,
      if(LOGICAL_DATA(isURL)[0] == 0) {
 	 struct stat tmp_stat;
 	 if(extId == NULL || stat(extId, &tmp_stat) < 0) {
-             PROBLEM "Can't find file %s", extId
-	     ERROR;
+             Rf_error("Can't find file %s", extId);
 	 }
      }
 
@@ -116,8 +115,7 @@ RS_XML(getDTD)(USER_OBJECT_ dtdFileName, USER_OBJECT_ externalId,
  }
 
  if(ctxt == NULL) {
-    PROBLEM "error creating XML parser for `%s'", extId
-    ERROR;
+     Rf_error("error creating XML parser for `%s'", extId);
  }
 
   ctxt->validate = 1;
@@ -160,8 +158,7 @@ RS_XML(getDTD)(USER_OBJECT_ dtdFileName, USER_OBJECT_ externalId,
       } else
         return(stop("DTDParseError", "error parsing %s", dtdName));
 
-   PROBLEM "error in DTD %s", extId
-   ERROR;
+      Rf_error("error in DTD %s", extId);
   }
 
   if(localAsText) {
@@ -248,12 +245,18 @@ struct ElementTableScanner {
   int counter;
 };
 
-#ifndef NO_XML_HASH_SCANNER_RETURN
-void *RS_xmlElementTableConverter(void *payload, void *data, xmlChar *name);
-void* RS_xmlEntityTableConverter(void *payload, void *data, xmlChar *name);
+#if LIBXML_VERSION >= 20908
+# define CONST const
 #else
-void RS_xmlElementTableConverter(void *payload, void *data, xmlChar *name);
-void RS_xmlEntityTableConverter(void *payload, void *data, xmlChar *name);
+# define CONST
+#endif
+
+#ifndef NO_XML_HASH_SCANNER_RETURN
+void *RS_xmlElementTableConverter(void *payload, void *data, CONST xmlChar *name);
+void* RS_xmlEntityTableConverter(void *payload, void *data, CONST xmlChar *name);
+#else
+void RS_xmlElementTableConverter(void *payload, void *data, CONST xmlChar *name);
+void RS_xmlEntityTableConverter(void *payload, void *data, CONST xmlChar *name);
 #endif
 
 
@@ -319,7 +322,7 @@ void*
 #else
 void
 #endif
-RS_xmlElementTableConverter(void *payload, void *data, xmlChar *name)
+RS_xmlElementTableConverter(void *payload, void *data, CONST xmlChar *name)
 {
   struct ElementTableScanner *scanData = (struct ElementTableScanner *)data;
 
@@ -395,7 +398,7 @@ void*
 #else
 void
 #endif
-RS_xmlEntityTableConverter(void *payload, void *data, xmlChar *name)
+RS_xmlEntityTableConverter(void *payload, void *data, CONST xmlChar *name)
 {
   struct ElementTableScanner *scanData = (struct ElementTableScanner *)data;
 
@@ -738,7 +741,7 @@ RS_XML(createDTDAttribute)(xmlAttributePtr val, xmlElementPtr el)
  INTEGER_DATA(VECTOR_ELT(ans, DTD_ATTRIBUTE_DEFAULT_SLOT))[0] =  val->def;
  SET_ENUM_NAME(AttributeDefaultNames, val->def, VECTOR_ELT(ans, DTD_ATTRIBUTE_DEFAULT_SLOT));
 
- if(val->type == XML_ATTRIBUTE_ENUMERATION) {
+ if(val->type == (xmlElementType)XML_ATTRIBUTE_ENUMERATION) {
    SET_VECTOR_ELT(ans, DTD_ATTRIBUTE_DEFAULT_VALUE_SLOT, RS_XML(AttributeEnumerationList)(val->tree, val, el));
  } else {
     SET_VECTOR_ELT(ans, DTD_ATTRIBUTE_DEFAULT_VALUE_SLOT, NEW_CHARACTER(1));
